Generate a commit message based on the contents of the diff message provided below.

If there are no changes in the diff, use a dot as the commit message.

Just the commit message. No commentary.

{{data}}